@@ -467,7 +467,10 @@ fish <- R6::R6Class(
 
     # @description Kill engine when object is collected
     finalize = function() {
-      self$run("quit")
+      tryCatch(
+        self$run("quit"),
+        error = function(err) { }
+      )
     }
   )
 )
@@ -494,3 +497,10 @@ fish_find <- function() {
 
   return(file)
 }
+
+# Work around R CMD check issue:
+# Namespaces in Imports field not imported from
+workaround <- function() {
+  processx::process
+  R6::R6Class
+}
